aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/file_downloader.php
diff options
context:
space:
mode:
authorJoas Schilling <nickvergessen@gmx.de>2015-01-30 18:02:04 +0100
committerJoas Schilling <nickvergessen@gmx.de>2015-01-30 18:05:13 +0100
commit69450c715244e41a26e63470bd292778ed25438a (patch)
tree94d2cfea914525a531ca91aa181dccb9295e1e7b /phpBB/phpbb/file_downloader.php
parente5f2eee167775dd8f7f1920a9d25fcf70919f8dd (diff)
downloadforums-69450c715244e41a26e63470bd292778ed25438a.tar
forums-69450c715244e41a26e63470bd292778ed25438a.tar.gz
forums-69450c715244e41a26e63470bd292778ed25438a.tar.bz2
forums-69450c715244e41a26e63470bd292778ed25438a.tar.xz
forums-69450c715244e41a26e63470bd292778ed25438a.zip
[ticket/13556] Fix exception translation with filedownloader
PHPBB3-13556
Diffstat (limited to 'phpBB/phpbb/file_downloader.php')
-rw-r--r--phpBB/phpbb/file_downloader.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/phpBB/phpbb/file_downloader.php b/phpBB/phpbb/file_downloader.php
index d717b394d5..ca8b1f4534 100644
--- a/phpBB/phpbb/file_downloader.php
+++ b/phpBB/phpbb/file_downloader.php
@@ -33,7 +33,7 @@ class file_downloader
* @return mixed File data as string if file can be read and there is no
* timeout, false if there were errors or the connection timed out
*
* @throws \RuntimeException If data can't be retrieved and no error
* message is returned
*/
public function get($host, $directory, $filename, $port = 80, $timeout = 6)
@@ -69,7 +69,7 @@ class file_downloader
}
else if (stripos($line, '404 not found') !== false)
{
- throw new \RuntimeException(array('FILE_NOT_FOUND', $filename));
+ throw new \phpbb\exception\runtime_exception('FILE_NOT_FOUND', array($filename));
}
}
@@ -77,7 +77,7 @@ class file_downloader
if (!empty($stream_meta_data['timed_out']) || time() >= $timer_stop)
{
- throw new \RuntimeException('FSOCK_TIMEOUT');
+ throw new \phpbb\exception\runtime_exception('FSOCK_TIMEOUT');
}
}
@fclose($socket);
@@ -33,7 +33,7 @@ class file_downloader
* timeout, false if there were errors or the connection timed out
*
- * @throws \RuntimeException If data can't be retrieved and no error
+ * @throws \phpbb\exception\runtime_exception If data can't be retrieved and no error
* message is returned
*/